@@ -18,6 +18,9 @@
  */
 package org.apache.maven.plugins.resources.filters;
 
+import javax.inject.Named;
+import javax.inject.Singleton;
+
 import java.io.File;
 import java.io.IOException;
 import java.util.ArrayList;
@@ -28,58 +31,50 @@ import org.apache.commons.io.FileUtils;
 import org.apache.maven.shared.filtering.MavenFilteringException;
 import org.apache.maven.shared.filtering.MavenResourcesExecution;
 import org.apache.maven.shared.filtering.MavenResourcesFiltering;
-import org.codehaus.plexus.component.annotations.Component;
 
 /**
  * @author Olivier Lamy
  * @since 2.5
  * @version $Id$
  */
-@Component(role = org.apache.maven.shared.filtering.MavenResourcesFiltering.class, hint = "itFilter")
-public class ItFilter
-    implements MavenResourcesFiltering
-{
+@Singleton
+@Named("itFilter")
+public class ItFilter implements MavenResourcesFiltering {
 
-
-    /** 
+    /**
      * @see org.apache.maven.shared.filtering.MavenResourcesFiltering#getDefaultNonFilteredFileExtensions()
      */
-    public List<String> getDefaultNonFilteredFileExtensions()
-    {
+    public List<String> getDefaultNonFilteredFileExtensions() {
         //  no op
         return Collections.emptyList();
     }
 
-    /** 
+    /**
      * @see org.apache.maven.shared.filtering.MavenResourcesFiltering#filteredFileExtension(String, List)
      */
-    public boolean filteredFileExtension( String fileName, List<String> userNonFilteredFileExtensions )
-    {
+    public boolean filteredFileExtension(String fileName, List<String> userNonFilteredFileExtensions) {
         return false;
     }
 
-    /** 
+    /**
      * @see org.apache.maven.shared.filtering.MavenResourcesFiltering#filterResources(org.apache.maven.shared.filtering.MavenResourcesExecution)
      */
-    public void filterResources( MavenResourcesExecution mavenResourcesExecution )
-        throws MavenFilteringException
-    {
+    public void filterResources(MavenResourcesExecution mavenResourcesExecution) throws MavenFilteringException {
         System.out.println("ItFilter filterResources");
-        try
-        {
-            File f = new File( mavenResourcesExecution.getOutputDirectory(), "foo.txt" );
+        try {
+            File f = new File(mavenResourcesExecution.getOutputDirectory(), "foo.txt");
             List<String> lines = new ArrayList<>();
-            
-            lines.add( "foo" );
-            lines.add( "version="+mavenResourcesExecution.getMavenProject().getVersion() );
-            lines.add( "toto=" + mavenResourcesExecution.getMavenSession().getSystemProperties().getProperty( "toto" ) );
-            FileUtils.writeLines( f, lines );
-        }
-        catch ( IOException e )
-        {
-            throw new MavenFilteringException( e.getMessage(), e );
-        }
 
+            lines.add("foo");
+            lines.add("version=" + mavenResourcesExecution.getMavenProject().getVersion());
+            lines.add("toto="
+                    + mavenResourcesExecution
+                            .getMavenSession()
+                            .getSystemProperties()
+                            .getProperty("toto"));
+            FileUtils.writeLines(f, lines);
+        } catch (IOException e) {
+            throw new MavenFilteringException(e.getMessage(), e);
+        }
     }
-
 }
